@@ -23,13 +23,6 @@
 #include "getfem/getfem_export.h"   /* export functions (save solution in a file)  */
 #include "getfem/getfem_derivatives.h"
 
-/* some Getfem++ types that we will be using */
-using bgeot::base_small_vector; /* special class for small (dim<16) vectors */
-using bgeot::base_node;  /* geometrical nodes(derived from base_small_vector)*/
-using bgeot::base_vector; /* dense vector. */
-using bgeot::scalar_type; /* = double */
-using bgeot::size_type;   /* = unsigned long */
-using bgeot::base_matrix; /* dense matrix. */
 
 /* definition of some matrix/vector types. 
  * default types of getfem_model_solvers.h
@@ -40,7 +33,7 @@ typedef getfem::modeling_standard_plain_vector  plain_vector;
 
 size_type is_global_dof_type(getfem::pdof_description dof){
 size_type global_dof = 0 ;
-   for (unsigned d = 0; d < 4 ; ++d){
+   for (dim_type d = 0; d < 4 ; ++d){
        if (dof == getfem::global_dof(d)) {
           global_dof = 1;
 	      }
@@ -59,12 +52,15 @@ int main(int argc, char *argv[]) {
        p.init();
     plain_vector U;
     p.mesh.write_to_file("mesh.m") ;
+    scalar_type ring_radius = p.PARAM.real_value("RING_RADIUS");
     if (p.PARAM.int_value("SOL_REF") == 0) {
        if (!p.solve(U)) GMM_ASSERT1(false, "Solve has failed");
-       p.compute_error(U) ;
+       p.compute_sif(U, ring_radius);
+       if (p.PARAM.int_value("COMPUTE_ERROR") == 1) p.compute_error(U) ;
     }
     if (p.PARAM.int_value("SOL_REF") == 1) {
        if (!p.solve_moment(U)) GMM_ASSERT1(false, "Solve has failed");
+       p.compute_sif(U, ring_radius);
 /*       cout << "valeur des dofs sur les bords horizontaux : \n" ;
        for (size_type i = 0; i< p.mf_u().nb_dof() ; i++){
           if ( gmm::abs(p.mf_u().point_of_dof(i)[1]) > 0.499){
@@ -88,11 +84,11 @@ int main(int argc, char *argv[]) {
     
     base_small_vector tab_fic(4) ;
     unsigned cpt = 0;
-    if (p.PARAM.int_value("ENRICHMENT_OPTION") == 3){  
-    // affichage des coeffs devant les singularits, avec le raccord integral
-	for (unsigned d=0; d < p.mf_u().nb_dof(); d += q) {
-		unsigned cv = p.mf_u().first_convex_of_dof(d) ;
-		getfem::pfem pf = p.mf_u().fem_of_element(cv);   
+    if (p.PARAM.int_value("ENRICHMENT_OPTION") == 3){
+    // affichage des coeffs devant les singularites, avec le raccord integral
+	for (size_type d=0; d < p.mf_u().nb_dof(); d += q) {
+		size_type cv = p.mf_u().first_convex_of_dof(d) ;
+		getfem::pfem pf = p.mf_u().fem_of_element(cv);
 		unsigned ld = unsigned(-1);
 		for (unsigned dd = 0; dd < p.mf_u().nb_dof_of_element(cv); dd += q) {
 		if (p.mf_u().ind_dof_of_element(cv)[dd] == d) {
@@ -112,7 +108,7 @@ int main(int argc, char *argv[]) {
 			cpt +=1 ;
 			}
 		}
-	}  
+	}
     // calcul des FIC k1 et k2 :
     scalar_type E, nu2 ;
     base_small_vector k(2) ;
@@ -205,25 +201,25 @@ int main(int argc, char *argv[]) {
 	   }
        }
     }
-          
-      
+
+
 
       if (p.PARAM.int_value("SOL_REF") == 1){
         scalar_type k1_exact = 3. * sqrt(p.PARAM.real_value("CRACK_SEMI_LENGTH")) / (2. * p.epsilon * p.epsilon) ;
-        cout << "exact SIF k1:" << k1_exact ;
-        cout << "\n(To multipliy by Mo, which is usually set to 1).\n" ; 
-	cout << "relative_error:" << gmm::abs(k[0] - k1_exact) / gmm::abs(k1_exact) ;
+        cout << "exact SIF k1:" << k1_exact << "\n" ;
+        cout << "(To multipliy by Mo, which is usually set to 1).\n" ; 
+        cout << "relative_error:" << gmm::abs(k[0] - k1_exact) / gmm::abs(k1_exact) << "\n" ;
       }
-    
+
     } // End printing SIFs
-     
+
     // --------------------------------------------------
     // Post-treatment for pretty printing of the solution
     // --------------------------------------------------
-    
-    int VTK_EXPORT = p.PARAM.int_value("VTK_EXPORT");
-    int MATLAB_EXPORT = p.PARAM.int_value("MATLAB_EXPORT");
-    int DX_EXPORT = p.PARAM.int_value("DX_EXPORT");
+
+    int VTK_EXPORT = int(p.PARAM.int_value("VTK_EXPORT"));
+    int MATLAB_EXPORT = int(p.PARAM.int_value("MATLAB_EXPORT"));
+    int DX_EXPORT = int(p.PARAM.int_value("DX_EXPORT"));
 	
     if (VTK_EXPORT || MATLAB_EXPORT || DX_EXPORT){
     // Post-traitement pour l'affichage, le plus simple :
@@ -231,13 +227,13 @@ int main(int argc, char *argv[]) {
     p.mls.global_cut_mesh(mcut);
     unsigned Q = p.mf_u().get_qdim();
     assert( Q == 1 ) ;
-    getfem::mesh_fem mf(mcut, Q);
+    getfem::mesh_fem mf(mcut, dim_type(Q));
     mf.set_classical_discontinuous_finite_element(3, 0.001);
     plain_vector V(mf.nb_dof()) ;
-    getfem::interpolation(p.mf_u(), mf, U, V);  
-    
+    getfem::interpolation(p.mf_u(), mf, U, V);
+
     size_type N = mcut.dim() ;
-    getfem::mesh_fem mf_grad(mcut, Q);
+    getfem::mesh_fem mf_grad(mcut, dim_type(Q));
     mf_grad.set_classical_discontinuous_finite_element(2, 0.001);
         // mf.set_finite_element
     //	(getfem::fem_descriptor("FEM_PK_DISCONTINUOUS(2, 2, 0.0001)"));
@@ -251,7 +247,7 @@ int main(int argc, char *argv[]) {
 
 
 //     // Printing the normal rotation (= derivative of the vertical displacement)
-//     if (p.PARAM.int_value("SHOW_DX") == 1 ){  // au lieu d'afficher la solution, on affiche sa drive en y
+//     if (p.PARAM.int_value("SHOW_DX") == 1 ){  // au lieu d'afficher la solution, on affiche sa derivee en y
 //        getfem::compute_gradient(mf, mf_grad, V, GRAD) ;
 //        gmm::resize(V, mf_grad.nb_dof()) ;
 //        for (unsigned i=0 ; i< mf_grad.nb_dof(); i++){
@@ -276,13 +272,13 @@ int main(int argc, char *argv[]) {
 // 	   << "mayavi -d " << p.datafilename
 // 	   << ".vtk -m BandedSurfaceMap -m Outline -f WarpScalar\n";
 //     }
-    
 
+    cout << "first part OK \n" ;
 
     getfem::stored_mesh_slice sl;
     getfem::mesh mcut_refined;
 
-    unsigned NX = p.PARAM.int_value("NX"), nn;
+    unsigned NX = unsigned(p.PARAM.int_value("NX")), nn;
     if (NX < 6) nn = 12;
     else if (NX < 12) nn = 8;
     else if (NX < 30) nn = 3;
@@ -301,16 +297,17 @@ int main(int argc, char *argv[]) {
       }
 
       if (dmin < 1e-5)
-	nrefine[cv] = nn*2;
+	nrefine[cv] = short_type(nn*2);
       else if (dmin < .1) 
-	nrefine[cv] = nn*2;
-      else nrefine[cv] = nn;
+	nrefine[cv] = short_type(nn*2);
+      else nrefine[cv] = short_type(nn);
       /*if (dmin < .01)
 	cout << "cv: "<< cv << ", dmin = " << dmin << "Pmin=" << Pmin << " " << nrefine[cv] << "\n";*/
     }
 
+    cout << "second part OK \n" ;
 
-    getfem::mesh_slicer slicer(mcut); 
+    getfem::mesh_slicer slicer(mcut);
     getfem::slicer_build_mesh bmesh(mcut_refined);
     slicer.push_back_action(bmesh);
     slicer.exec(nrefine, getfem::mesh_region::all_convexes());
@@ -323,11 +320,11 @@ int main(int argc, char *argv[]) {
     mim_refined.set_integration_method(getfem::int_method_descriptor
 				       ("IM_TRIANGLE(6)"));
 
-    getfem::mesh_fem mf_refined(mcut_refined, Q);
+    getfem::mesh_fem mf_refined(mcut_refined, dim_type(Q));
     mf_refined.set_classical_discontinuous_finite_element(2, 0.001);
     plain_vector W(mf_refined.nb_dof());
 
-    
+    cout << "OK before last interpolation \n" ;
     getfem::interpolation(p.mf_u(), mf_refined, U, W);
     
 //     getfem::mesh_fem mf_grad(mcut, 2) ;
@@ -346,7 +343,7 @@ int main(int argc, char *argv[]) {
 	"mayavi -d " << p.datafilename  << ".vtk -f "
 	"WarpScalar -m BandedSurfaceMap -m Outline\n";
 
-      p.exact_sol.mf.set_qdim(Q);
+      p.exact_sol.mf.set_qdim(dim_type(Q));
       assert(p.exact_sol.mf.nb_dof() == p.exact_sol.U.size());   
       plain_vector EXACT(mf_refined.nb_dof());
       getfem::interpolation(p.exact_sol.mf, mf_refined, 
@@ -377,7 +374,7 @@ int main(int argc, char *argv[]) {
       cout << "exporting solution to " << p.datafilename + ".mf" << " and " << p.datafilename << ".U\n";
       mf_refined.write_to_file(p.datafilename + ".mf", true);
       gmm::vecsave(p.datafilename + ".U", W);
-      p.exact_sol.mf.set_qdim(Q);
+      p.exact_sol.mf.set_qdim(dim_type(Q));
       assert(p.exact_sol.mf.nb_dof() == p.exact_sol.U.size());   // ??
       plain_vector EXACT(mf_refined.nb_dof());
       getfem::interpolation(p.exact_sol.mf, mf_refined, 
