@@ -44,6 +44,7 @@ using bgeot::base_node;  /* geometrical nodes(derived from base_small_vector)*/
 using bgeot::scalar_type; /* = double */
 using bgeot::short_type;  /* = short */
 using bgeot::size_type;   /* = unsigned long */
+using bgeot::dim_type;
 using bgeot::base_matrix; /* small dense matrix. */
 
 /* definition of some matrix/vector types. These ones are built
@@ -64,80 +65,113 @@ double u_alpha = 1.5;
 double u_B = 20;
 double u_n = 7.0;
 double dtheta = M_PI/36;
+
 double u_exact(const base_node &p) {
-  double norm_sqr = gmm::vect_norm2_sqr(p);
+  double R = Radius, r=gmm::vect_norm2(p), T=atan2(p[1], p[0])+dtheta;
   switch (u_version) {
     case 0: {
       double sum = std::accumulate(p.begin(), p.end(), double(0));
       
-      return 5.0 * sin(sum) * (norm_sqr - Radius*Radius);
+      return 5.0 * sin(sum) * (r*r - Radius*Radius);
     }
     case 1: {
-      double r=gmm::vect_norm2(p), A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n;
-      return Radius*Radius - r*r *(1+A*(1.0 + sin(n*T)));
+      double A=u_alpha, n=u_n;
+      return (R*R - r*r *(1+A*(1.0 + sin(n*T))));
     }
     case 2: {
-      double r=gmm::vect_norm2(p), A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n,B=u_B;
-      return (Radius*Radius - r*r *(1+A*(1.0 + sin(n*T)))) * cos(B*r);      
+      double A=u_alpha, n=u_n, B=u_B;
+      return (R*R - r*r *(1+A*(1.0 + sin(n*T)))) * cos(B*r);      
+    }
+    case 3: {
+      double A=u_alpha, n=u_n;
+      return 5*(R*R*R*R - r*r*r*r*(1+A*(1.0 + sin(n*T))));      
     }
   }
   GMM_ASSERT1(false, "Invalid exact solution");
 }
 
 double g_exact(const base_node &p) {
-  double norm_sqr = gmm::vect_norm2_sqr(p);
+  // value of the normal derivative. Due to the pb idem than the opposite of
+  // norm of the gradient.
+  double R = Radius, r=gmm::vect_norm2(p);
   switch (u_version) {
-    case 0: {
-      double sum = std::accumulate(p.begin(), p.end(), double(0));
-      if (norm_sqr < 1e-10) norm_sqr = 1e-10;
-      return 5.0 * (sum * cos(sum) * (norm_sqr - Radius*Radius)
-		    + 2.0 * norm_sqr * sin(sum)) / sqrt(norm_sqr);
-    }
-    case 1: {
-      double r=gmm::vect_norm2(p), A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n;
-      return - sqrt(r*r*pow(2.0*sin(T)+2.0*sin(T)*A+2.0*sin(T)*A*sin(n*T)+cos(T)*A*cos(n*T)*n,2.0)+r*r*pow(-2.0*cos(T)-2.0*cos(T)*A-2.0*cos(T)*A*sin(n*T)+sin(T)*A*cos(n*T)*n,2.0));
-    } 
-    case 2: {
-      double R=Radius, r=gmm::vect_norm2(p), A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n,B=u_B;
-      if (gmm::abs(r) < 1e-10) r = 1e-10;
-      return -(4.0*r*cos(B*r)+8.0*r*cos(B*r)*A+8.0*r*cos(B*r)*A*A+2.0*sin(B*r)*B*R*R-2.0*sin(B*r)*B*r*r+r*A*A*pow(cos(n*T),2.0)*n*n*cos(B*r)+8.0*r*cos(B*r)*A*A*sin(n*T)-4.0*sin(B*r)*B*r*r*A*sin(n*T)+2.0*sin(B*r)*B*r*r*A*A*pow(cos(n*T),2.0)-4.0*r*cos(B*r)*A*A*pow(cos(n*T),2.0)+8.0*r*cos(B*r)*A*sin(n*T)-4.0*sin(B*r)*B*r*r*A*A*sin(n*T)-4.0*sin(B*r)*B*r*r*A*A-4.0*sin(B*r)*B*r*r*A+2.0*sin(B*r)*B*R*R*A+2.0*sin(B*r)*B*R*R*A*sin(n*T))/sqrt(A*A*pow(cos(n*T),2.0)*n*n+4.0+8.0*A+8.0*A*sin(n*T)+8.0*A*A+8.0*A*A*sin(n*T)-4.0*A*A*pow(cos(n*T),2.0));
-    }
+  case 0: {
+    double sum=std::accumulate(p.begin(), p.end(), double(0)), norm_sqr = r*r;
+    if (norm_sqr < 1e-10) norm_sqr = 1e-10;
+    return 5.0 * (sum * cos(sum) * (norm_sqr - R*R)
+		  + 2.0 * norm_sqr * sin(sum)) / sqrt(norm_sqr);
+  }
+  case 1: {
+    double A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n;
+    return - sqrt(r*r*pow(2.0*sin(T)+2.0*sin(T)*A+2.0*sin(T)*A*sin(n*T)+cos(T)*A*cos(n*T)*n,2.0)+r*r*pow(-2.0*cos(T)-2.0*cos(T)*A-2.0*cos(T)*A*sin(n*T)+sin(T)*A*cos(n*T)*n,2.0));
+  } 
+  case 2: {
+    double A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n,B=u_B;
+    if (gmm::abs(r) < 1e-10) r = 1e-10;
+    return -(4.0*r*cos(B*r)+8.0*r*cos(B*r)*A+8.0*r*cos(B*r)*A*A
+	     +2.0*sin(B*r)*B*R*R-2.0*sin(B*r)*B*r*r
+	     +r*A*A*pow(cos(n*T),2.0)*n*n*cos(B*r)+8.0*r*cos(B*r)*A*A*sin(n*T)
+	     -4.0*sin(B*r)*B*r*r*A*sin(n*T)
+	     +2.0*sin(B*r)*B*r*r*A*A*pow(cos(n*T),2.0)
+	     -4.0*r*cos(B*r)*A*A*pow(cos(n*T),2.0)+8.0*r*cos(B*r)*A*sin(n*T)
+	     -4.0*sin(B*r)*B*r*r*A*A*sin(n*T)-4.0*sin(B*r)*B*r*r*A*A
+	     -4.0*sin(B*r)*B*r*r*A+2.0*sin(B*r)*B*R*R*A
+	     +2.0*sin(B*r)*B*R*R*A*sin(n*T))
+      / sqrt(A*A*pow(cos(n*T),2.0)*n*n +4.0+8.0*A+8.0*A*sin(n*T)
+	     +8.0*A*A+8.0*A*A*sin(n*T)-4.0*A*A*pow(cos(n*T),2.0));
+  }
+  case 3: {
+    double A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n;
+    return -5*r*r*r*sqrt(16.0 + 32.0*A*A + 32.0*A*sin(n*T) + 32.0*A
+			+ 32.0*A*A*sin(n*T) - 16*gmm::sqr(A*cos(n*T))
+		       + gmm::sqr(A*cos(n*T)*n));
+  }   
   }
   return 0;
 }
 
 double rhs(const base_node &p) {
+  double R = Radius, r=gmm::vect_norm2(p);
   switch (u_version) {
-    case 0: {
-      double sum = std::accumulate(p.begin(), p.end(), double(0));
-      double norm_sqr = gmm::vect_norm2_sqr(p);
-      double N = double(gmm::vect_size(p));
-      return 5.0 * (N * sin(sum) * (norm_sqr - Radius*Radius-2.0)
-		    - 4.0 * sum * cos(sum));
-    }
-    case 1: {
-      double A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n;
-      return -(-4.0-4.0*A-4.0*A*sin(n*T)+A*sin(n*T)*n*n);
-    }
-    case 2: {
-      double R=Radius, r=gmm::vect_norm2(p), A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n,B=u_B;
-      if (gmm::abs(r) < 1e-10) r = 1e-10;
-      return (4.0*r*cos(B*r)*A*sin(n*T)-5.0*sin(B*r)*B*r*r*A+4.0*r*cos(B*r)+4.0*
-r*cos(B*r)*A+sin(B*r)*B*R*R-5.0*sin(B*r)*B*r*r-5.0*sin(B*r)*B*r*r*A*sin(n*T)-r*
-r*r*cos(B*r)*B*B-r*A*sin(n*T)*n*n*cos(B*r)+r*cos(B*r)*B*B*R*R-r*r*r*cos(B*r)*B*
-	      B*A-r*r*r*cos(B*r)*B*B*A*sin(n*T))/r;
-    }
+  case 0: {
+    double sum = std::accumulate(p.begin(), p.end(), double(0));
+    double norm_sqr = r*r, N = double(gmm::vect_size(p));
+    return 5.0 * (N * sin(sum) * (norm_sqr - R*R-2.0)
+		  - 4.0 * sum * cos(sum));
+  }
+  case 1: {
+    double A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n;
+    return -(-4.0-4.0*A-4.0*A*sin(n*T)+A*sin(n*T)*n*n);
+  }
+  case 2: {
+    double A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n, B=u_B;
+    if (gmm::abs(r) < 1e-10) r = 1e-10;
+    return (4.0*r*cos(B*r)*A*sin(n*T)-5.0*sin(B*r)*B*r*r*A+4.0*r*cos(B*r)
+	    +4.0*r*cos(B*r)*A+sin(B*r)*B*R*R-5.0*sin(B*r)*B*r*r
+	    -5.0*sin(B*r)*B*r*r*A*sin(n*T)-r*r*r*cos(B*r)*B*B
+	    -r*A*sin(n*T)*n*n*cos(B*r)+r*cos(B*r)*B*B*R*R
+	    -r*r*r*cos(B*r)*B*B*A-r*r*r*cos(B*r)*B*B*A*sin(n*T))/r;
+  }
+  case 3: {
+    double A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n;
+    return -5*r*r*(-16.0-16.0*A*sin(n*T)-16.0*A+A*sin(n*T)*n*n);
+  }
   }
   return 0;
 }
 
 double ls_value(const base_node &p) {
+  double R = Radius, r=gmm::vect_norm2(p);
   switch (u_version) {
-    case 0: return gmm::vect_norm2_sqr(p)-Radius*Radius;
-    case 1: case 2: {
-      double r=gmm::vect_norm2(p), A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n;
-      return (r*r*(1+A*(1.0 + sin(n*T))) - Radius*Radius) / 15.0;
-    }
+  case 0: return gmm::vect_norm2_sqr(p) - R*R;
+  case 1: case 2: {
+    double A=u_alpha, T=atan2(p[1],p[0])+dtheta, n=u_n;
+    return -(R*R - r*r*(1+A*(1.0 + sin(n*T)))) / 15.0;
+  }
+  case 3: {
+    double A=u_alpha, T=atan2(p[1], p[0])+dtheta, n=u_n;
+    return -(R*R*R*R - r*r*r*r*(1+A*(1.0 + sin(n*T)))) / 4.0;      
+  } 
   }
   return 0;
 }
@@ -149,7 +183,7 @@ double ls_value(const base_node &p) {
 void test_mim(getfem::mesh_im_level_set &mim, getfem::mesh_fem &mf_rhs,
 	      bool bound) {
   if (!u_version) {
-    unsigned N =  mim.linked_mesh().dim();
+    unsigned N =  unsigned(mim.linked_mesh().dim());
     size_type nbdof = mf_rhs.nb_dof();
     plain_vector V(nbdof), W(1);
     std::fill(V.begin(), V.end(), 1.0);
@@ -187,7 +221,7 @@ template<typename VECT1> class level_set_unit_normal
 public:
   level_set_unit_normal(const getfem::mesh_fem &mf_, const VECT1 &U_) 
     : mf(mf_), U(U_), N(mf_.linked_mesh().dim()), gradU(1, N)
-  { sizes_.resize(1); sizes_[0] = N; }
+  { sizes_.resize(1); sizes_[0] = short_type(N); }
   const bgeot::multi_index &sizes() const {  return sizes_; }
   virtual void compute(getfem::fem_interpolation_context& ctx,
 		       bgeot::base_tensor &t) {
@@ -332,7 +366,7 @@ int main(int argc, char *argv[]) {
   // Read parameters.
   bgeot::md_param PARAM;
   PARAM.read_command_line(argc, argv);
-  u_version = PARAM.int_value("EXACT_SOL", "Which exact solution");
+  u_version = int(PARAM.int_value("EXACT_SOL", "Which exact solution"));
   
   // Load the mesh
   getfem::mesh mesh;
@@ -350,13 +384,13 @@ int main(int argc, char *argv[]) {
   cout << "h = " << h << endl;
   
   // Level set definition
-  unsigned lsdeg = PARAM.int_value("LEVEL_SET_DEGREE", "level set degree");
+  unsigned lsdeg = unsigned(PARAM.int_value("LEVEL_SET_DEGREE", "level set degree"));
   bool simplify_level_set = 
     (PARAM.int_value("SIMPLIFY_LEVEL_SET",
 		     "simplification or not of the level sets") != 0);
   Radius = PARAM.real_value("RADIUS", "Domain radius");
-  getfem::level_set ls(mesh, lsdeg);
-  getfem::level_set lsup(mesh, lsdeg, true), lsdown(mesh, lsdeg, true);
+  getfem::level_set ls(mesh, dim_type(lsdeg));
+  getfem::level_set lsup(mesh, dim_type(lsdeg), true), lsdown(mesh, dim_type(lsdeg), true);
   const getfem::mesh_fem &lsmf = ls.get_mesh_fem();
   for (unsigned i = 0; i < lsmf.nb_dof(); ++i) {
     lsup.values()[i] = lsdown.values()[i] = ls.values()[i]
@@ -459,8 +493,8 @@ int main(int argc, char *argv[]) {
   getfem::asm_mass_matrix(B, mimbounddown, mf_mult, mf);
 
   int stabilized_dirichlet =
-    PARAM.int_value("STABILIZED_DIRICHLET", "Stabilized version of "
-		    "Dirichlet condition or not");
+    int(PARAM.int_value("STABILIZED_DIRICHLET", "Stabilized version of "
+			"Dirichlet condition or not"));
   scalar_type dir_gamma0(0);
   sparse_matrix MA(nb_dof_mult, nb_dof_mult), KA(nb_dof, nb_dof);
   sparse_matrix BA(nb_dof_mult, nb_dof);
@@ -627,10 +661,10 @@ int main(int argc, char *argv[]) {
     else Eint[i] = 0.0;
   cout << "Linfty error: " << 100.0 * errmax / exactmax << "%" << endl;
   cout << "L2 error: " << 100.0
-    * getfem::asm_L2_dist(mim, mf_rhs, Uint, mf_rhs, Vint)
+    * getfem::asm_L2_dist(mim, mf, U, mf_rhs, Vint)
     / getfem::asm_L2_norm(mim, mf_rhs, Vint) << "%" << endl;
   cout << "H1 error: " << 100.0
-    * getfem::asm_H1_dist(mim, mf_rhs, Uint, mf_rhs, Vint)
+    * getfem::asm_H1_dist(mim, mf, U, mf_rhs, Vint)
     / getfem::asm_H1_norm(mim, mf_rhs, Vint) << "%" << endl;
 
   // computation of error on multipliers.
