@@ -55,7 +55,7 @@ static void gf_mesh_im_set_integ_(getfem::mesh_im *mim, getfemint::mexargs_in& i
    method */
 static void gf_mesh_im_set_classical_integ(getfem::mesh_im *mim, getfemint::mexargs_in& in) {
   dim_type IM_DEGREE = dim_type(-1);
-  if (in.remaining()) IM_DEGREE = in.pop().to_integer(-1,255);
+  if (in.remaining()) IM_DEGREE = dim_type(in.pop().to_integer(-1,255));
   dal::bit_vector bv;
   if (in.remaining() == 1) {
     bv = in.pop().to_bit_vector(&mim->linked_mesh().convex_index(), -1);
@@ -80,7 +80,7 @@ void gf_mesh_im_set_integ(getfem::mesh_im *mim, getfemint::mexargs_in& in) {
   
   @SET MESHIM:SET('integ')
 
-  $Id: gf_mesh_im_set.cc 2722 2007-12-04 15:26:17Z renard $
+  $Id: gf_mesh_im_set.cc 2810 2008-09-04 14:47:57Z renard $
 MLABCOM*/
 
 void gf_mesh_im_set(getfemint::mexargs_in& in, getfemint::mexargs_out& out)
