@@ -1,13 +1,14 @@
 // -*- c++ -*- (enables emacs c++ mode)
 //========================================================================
 //
-// Copyright (C) 0-2006 Yves Renard, Julien Pommier.
+// Copyright (C) 2004-2008 Yves Renard, Julien Pommier.
 //
 // This file is a part of GETFEM++
 //
 // Getfem++ is free software; you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
+// published by the Free Software Foundation; version 2.1 of the License,
+// or (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -195,7 +196,7 @@ gc_alloc(gcollect *gc, size_t sz) {
   if (p) {
     gc->allocated = ptr_collect_push_front(gc->allocated, p);
   } else {
-    PyErr_Format(PyExc_RuntimeError, "could not allocate %d bytes: memory exhausted", sz);
+    PyErr_Format(PyExc_RuntimeError, "could not allocate %d bytes: memory exhausted", (int)sz);
   }
   return p;
 }
