@@ -17,14 +17,14 @@
 // along  with  this program;  if not, write to the Free Software Foundation,
 // Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// As a special exception, you may use this file as part of a free software
-// library without restriction.  Specifically, if other files instantiate
-// templates or use macros or inline functions from this file, or you compile
-// this file and link it with other files to produce an executable, this
-// file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however
-// invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.
+// As a special exception, you  may use  this file  as it is a part of a free
+// software  library  without  restriction.  Specifically,  if   other  files
+// instantiate  templates  or  use macros or inline functions from this file,
+// or  you compile this  file  and  link  it  with other files  to produce an
+// executable, this file  does  not  by itself cause the resulting executable
+// to be covered  by the GNU Lesser General Public License.  This   exception
+// does not  however  invalidate  any  other  reasons why the executable file
+// might be covered by the GNU Lesser General Public License.
 //
 //===========================================================================
 
@@ -191,7 +191,8 @@ namespace getfem {
       strides.resize(vdim.size()+1);
       add_child(a);
       strides[0] = 1;
-      for (size_type i=0; i < vdim.size(); ++i) strides[i+1] = strides[i]*vdim[i].dim;
+      for (size_type i=0; i < vdim.size(); ++i)
+	strides[i+1] = strides[i]*int(vdim[i].dim);
       if (gmm::vect_size(v) != size_type(strides[vdim.size()])) 
 	ASM_THROW_TENSOR_ERROR("wrong size for output vector: supplied vector size is " << 
 			       gmm::vect_size(v) << " while it should be " << strides[vdim.size()]);      
@@ -307,7 +308,7 @@ namespace getfem {
       size_type ppos;
       do {
 	ppos = 0;
-	for (unsigned i = 0; i < mti.ndim(); ++i) ppos+=str[i][mti.index(i)];
+	for (dim_type i = 0; i < mti.ndim(); ++i) ppos+=str[i][mti.index(i)];
 	mti.p(0) = v[ppos];
       } while (mti.qnext1());
     }
