@@ -62,7 +62,7 @@ namespace getfem {
   void fem_product::real_base_value(const fem_interpolation_context &c,
 				      base_tensor &t, bool) const {
     bgeot::multi_index mi(2);
-    mi[1] = target_dim(); mi[0] = nb_dof(0);
+    mi[1] = target_dim(); mi[0] = short_type(nb_dof(0));
     t.adjust_sizes(mi);
     base_tensor::iterator it = t.begin(), itf;
 
@@ -89,7 +89,8 @@ namespace getfem {
   void fem_product::real_grad_base_value(const fem_interpolation_context &c,
 					 base_tensor &t, bool) const {
     bgeot::multi_index mi(3);
-    mi[2] = c.N(); mi[1] = target_dim(); mi[0] = nb_dof(0);
+    mi[2] = short_type(c.N()); mi[1] = target_dim();
+    mi[0] = short_type(nb_dof(0));
     t.adjust_sizes(mi);
     base_tensor::iterator it = t.begin();
     
@@ -120,7 +121,8 @@ namespace getfem {
   void fem_product::real_hess_base_value(const fem_interpolation_context &c,
 				  base_tensor &t, bool) const {
     bgeot::multi_index mi(4);
-    mi[3] = mi[2] = c.N(); mi[1] = target_dim(); mi[0] = nb_dof(0);
+    mi[3] = mi[2] = short_type(c.N()); mi[1] = target_dim();
+    mi[0] = short_type(nb_dof(0));
     t.adjust_sizes(mi);
     base_tensor::iterator it = t.begin();
     
